@@ -22,6 +22,8 @@ parser = argparse.ArgumentParser()
 parser.add_argument('-D', action='append', default=[], dest='sets',
                     help='Set an option to the given value.')
 parser.add_argument('directory', nargs='*')
+parser.add_argument('--clearcache', action='store_true', default=False,
+                    help='Clear cached state (e.g. found dependencies)')
 
 class ConfException(mesonlib.MesonException):
     def __init__(self, *args, **kwargs):
@@ -42,13 +44,16 @@ class Conf:
             raise ConfException('Version mismatch (%s vs %s)' %
                                 (coredata.version, self.coredata.version))
 
+    def clear_cache(self):
+        self.coredata.deps = {}
+
     def save(self):
         # Only called if something has changed so overwrite unconditionally.
         with open(self.coredata_file, 'wb') as f:
             pickle.dump(self.coredata, f)
         # We don't write the build file because any changes to it
-        # are erased when Meson is executed the nex time, i.e. the next
-        # time Ninja is run.
+        # are erased when Meson is executed the next time, i.e. whne
+        # Ninja is run.
 
     def print_aligned(self, arr):
         if len(arr) == 0:
@@ -67,8 +72,8 @@ class Conf:
 
         if longest_possible_value > 0:
             titles[3] = 'Possible Values'
-        print('  %s%s %s%s %s%s %s' % (titles[0], ' '*(longest_name - len(titles[0])), titles[1], ' '*(longest_descr - len(titles[1])), titles[2], ' '*(longest_value - len(titles[2])), titles[3]))
-        print('  %s%s %s%s %s%s %s' % ('-'*len(titles[0]), ' '*(longest_name - len(titles[0])), '-'*len(titles[1]), ' '*(longest_descr - len(titles[1])), '-'*len(titles[2]), ' '*(longest_value - len(titles[2])), '-'*len(titles[3])))
+        print('  %s%s %s%s %s%s %s' % (titles[0], ' ' * (longest_name - len(titles[0])), titles[1], ' ' * (longest_descr - len(titles[1])), titles[2], ' ' * (longest_value - len(titles[2])), titles[3]))
+        print('  %s%s %s%s %s%s %s' % ('-' * len(titles[0]), ' ' * (longest_name - len(titles[0])), '-' * len(titles[1]), ' ' * (longest_descr - len(titles[1])), '-' * len(titles[2]), ' ' * (longest_value - len(titles[2])), '-' * len(titles[3])))
         for i in arr:
             name = i[0]
             descr = i[1]
@@ -80,9 +85,9 @@ class Conf:
                     possible_values = '[%s]' % ', '.join(map(str, i[3]))
             elif i[3]:
                 possible_values = i[3] if isinstance(i[3], str) else str(i[3]).lower()
-            namepad = ' '*(longest_name - len(name))
-            descrpad = ' '*(longest_descr - len(descr))
-            valuepad = ' '*(longest_value - len(str(value)))
+            namepad = ' ' * (longest_name - len(name))
+            descrpad = ' ' * (longest_descr - len(descr))
+            valuepad = ' ' * (longest_value - len(str(value)))
             f = '  %s%s %s%s %s%s %s' % (name, namepad, descr, descrpad, value, valuepad, possible_values)
             print(f)
 
@@ -104,7 +109,7 @@ class Conf:
                 tgt.set_value(v)
             elif k.endswith('_link_args'):
                 lang = k[:-10]
-                if not lang in self.coredata.external_link_args:
+                if lang not in self.coredata.external_link_args:
                     raise ConfException('Unknown language %s in linkargs.' % lang)
                 # TODO, currently split on spaces, make it so that user
                 # can pass in an array string.
@@ -112,7 +117,7 @@ class Conf:
                 self.coredata.external_link_args[lang] = newvalue
             elif k.endswith('_args'):
                 lang = k[:-5]
-                if not lang in self.coredata.external_args:
+                if lang not in self.coredata.external_args:
                     raise ConfException('Unknown language %s in compile args' % lang)
                 # TODO same fix as above
                 newvalue = v.split()
@@ -120,7 +125,6 @@ class Conf:
             else:
                 raise ConfException('Unknown option %s.' % k)
 
-
     def print_conf(self):
         print('Core properties:')
         print('  Source dir', self.build.environment.source_dir)
@@ -128,9 +132,9 @@ class Conf:
         print('')
         print('Core options:')
         carr = []
-        for key in [ 'buildtype', 'warning_level', 'werror', 'strip', 'unity', 'default_library' ]:
+        for key in ['buildtype', 'warning_level', 'werror', 'strip', 'unity', 'default_library']:
             carr.append([key, coredata.get_builtin_option_description(key),
-                self.coredata.get_builtin_option(key), coredata.get_builtin_option_choices(key)])
+                         self.coredata.get_builtin_option(key), coredata.get_builtin_option_choices(key)])
         self.print_aligned(carr)
         print('')
         print('Base options:')
@@ -178,9 +182,9 @@ class Conf:
                     'sysconfdir',
                     'localstatedir',
                     'sharedstatedir',
-                ]:
+                    ]:
             parr.append([key, coredata.get_builtin_option_description(key),
-                self.coredata.get_builtin_option(key), coredata.get_builtin_option_choices(key)])
+                         self.coredata.get_builtin_option(key), coredata.get_builtin_option_choices(key)])
         self.print_aligned(parr)
         print('')
         print('Project options:')
@@ -195,18 +199,18 @@ class Conf:
                 opt = options[key]
                 if (opt.choices is None) or (len(opt.choices) == 0):
                     # Zero length list or string
-                    choices = '';
+                    choices = ''
                 else:
                     # A non zero length list or string, convert to string
-                    choices = str(opt.choices);
+                    choices = str(opt.choices)
                 optarr.append([key, opt.description, opt.value, choices])
             self.print_aligned(optarr)
         print('')
         print('Testing options:')
         tarr = []
-        for key in [ 'stdsplit', 'errorlogs' ]:
+        for key in ['stdsplit', 'errorlogs']:
             tarr.append([key, coredata.get_builtin_option_description(key),
-                self.coredata.get_builtin_option(key), coredata.get_builtin_option_choices(key)])
+                         self.coredata.get_builtin_option(key), coredata.get_builtin_option_choices(key)])
         self.print_aligned(tarr)
 
 def run(args):
@@ -224,15 +228,21 @@ def run(args):
         builddir = options.directory[0]
     try:
         c = Conf(builddir)
+        save = False
         if len(options.sets) > 0:
             c.set_options(options.sets)
-            c.save()
+            save = True
+        elif options.clearcache:
+            c.clear_cache()
+            save = True
         else:
             c.print_conf()
+        if save:
+            c.save()
     except ConfException as e:
         print('Meson configurator encountered an error:\n')
         print(e)
-        return(1)
+        return 1
     return 0
 
 if __name__ == '__main__':
