@@ -1,4 +1,4 @@
-# Copyright 2014-2016 The Meson development team
+# Copyright 2014-2017 The Meson development team
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -47,7 +47,7 @@ class Lexer:
             ('eol_cont', re.compile(r'\\\n')),
             ('eol', re.compile(r'\n')),
             ('multiline_string', re.compile(r"'''(.|\n)*?'''", re.M)),
-            ('comment', re.compile(r'\#.*')),
+            ('comment', re.compile(r'#.*')),
             ('lparen', re.compile(r'\(')),
             ('rparen', re.compile(r'\)')),
             ('lbracket', re.compile(r'\[')),
@@ -60,11 +60,11 @@ class Lexer:
             ('plus', re.compile(r'\+')),
             ('dash', re.compile(r'-')),
             ('star', re.compile(r'\*')),
-            ('percent', re.compile(r'\%')),
+            ('percent', re.compile(r'%')),
             ('fslash', re.compile(r'/')),
             ('colon', re.compile(r':')),
             ('equal', re.compile(r'==')),
-            ('nequal', re.compile(r'\!=')),
+            ('nequal', re.compile(r'!=')),
             ('assign', re.compile(r'=')),
             ('le', re.compile(r'<=')),
             ('lt', re.compile(r'<')),
@@ -76,18 +76,18 @@ class Lexer:
     def lex(self, code, subdir):
         lineno = 1
         line_start = 0
-        loc = 0;
+        loc = 0
         par_count = 0
         bracket_count = 0
         col = 0
-        while(loc < len(code)):
+        while loc < len(code):
             matched = False
             value = None
             for (tid, reg) in self.token_specification:
                 mo = reg.match(code, loc)
                 if mo:
                     curline = lineno
-                    col = mo.start()-line_start
+                    col = mo.start() - line_start
                     matched = True
                     span_start = loc
                     loc = mo.end()
@@ -107,8 +107,10 @@ class Lexer:
                     elif tid == 'dblquote':
                         raise ParseException('Double quotes are not supported. Use single quotes.', lineno, col)
                     elif tid == 'string':
-                        value = match_text[1:-1].replace(r"\'", "'").replace(r" \\ ".strip(), r" \ ".strip())\
-                        .replace("\\n", "\n")
+                        value = match_text[1:-1]\
+                            .replace(r"\'", "'")\
+                            .replace(r" \\ ".strip(), r" \ ".strip())\
+                            .replace("\\n", "\n")
                     elif tid == 'multiline_string':
                         tid = 'string'
                         value = match_text[3:-3]
@@ -177,7 +179,7 @@ class ArrayNode:
 
 class EmptyNode:
     def __init__(self):
-        self.subdir =''
+        self.subdir = ''
         self.lineno = 0
         self.colno = 0
         self.value = None
@@ -207,7 +209,7 @@ class ComparisonNode:
         self.ctype = ctype
 
 class ArithmeticNode:
-    def __init__(self,operation, left, right):
+    def __init__(self, operation, left, right):
         self.subdir = left.subdir
         self.lineno = left.lineno
         self.colno = left.colno
@@ -272,7 +274,7 @@ class PlusAssignmentNode:
         assert(isinstance(var_name, str))
         self.value = value
 
-class ForeachClauseNode():
+class ForeachClauseNode:
     def __init__(self, lineno, colno, varname, items, block):
         self.lineno = lineno
         self.colno = colno
@@ -280,28 +282,28 @@ class ForeachClauseNode():
         self.items = items
         self.block = block
 
-class IfClauseNode():
+class IfClauseNode:
     def __init__(self, lineno, colno):
         self.lineno = lineno
         self.colno = colno
         self.ifs = []
         self.elseblock = EmptyNode()
 
-class UMinusNode():
+class UMinusNode:
     def __init__(self, current_location, value):
         self.subdir = current_location.subdir
         self.lineno = current_location.lineno
         self.colno = current_location.colno
         self.value = value
 
-class IfNode():
+class IfNode:
     def __init__(self, lineno, colno, condition, block):
         self.lineno = lineno
         self.colno = colno
         self.condition = condition
         self.block = block
 
-class TernaryNode():
+class TernaryNode:
     def __init__(self, lineno, colno, condition, trueblock, falseblock):
         self.lineno = lineno
         self.colno = colno
@@ -309,7 +311,7 @@ class TernaryNode():
         self.trueblock = trueblock
         self.falseblock = falseblock
 
-class ArgumentNode():
+class ArgumentNode:
     def __init__(self, token):
         self.lineno = token.lineno
         self.colno = token.colno
@@ -329,7 +331,7 @@ class ArgumentNode():
         if self.num_kwargs() > 0:
             self.order_error = True
         if not isinstance(statement, EmptyNode):
-            self.arguments = self.arguments + [statement]
+            self.arguments += [statement]
 
     def set_kwarg(self, name, value):
         self.kwargs[name] = value
@@ -519,7 +521,7 @@ class Parser:
     def e9(self):
         t = self.current
         if self.accept('true'):
-            return BooleanNode(t, True);
+            return BooleanNode(t, True)
         if self.accept('false'):
             return BooleanNode(t, False)
         if self.accept('id'):
